import java.io.Serializable;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;

import org.apache.beehive.netui.pageflow.Forward;
import org.apache.beehive.netui.pageflow.PageFlowController;
import org.apache.beehive.netui.pageflow.annotations.Jpf;

@Jpf.Controller
public class Controller extends PageFlowController {
    @Jpf.Action(
        forwards={
           @Jpf.Forward(name="authorized", path="/mydiary/index.jsp"),
           @Jpf.Forward(name="not_authorized", path="/login.jsp")
        }
    )
    public Forward begin() {
        HttpServletRequest request = getRequest();
        HttpSession session = request.getSession();
        String username = (String)session.getAttribute("username");
        if (isAuthorized(username)) {
            return new Forward("authorized");
        } else {
            return new Forward("not_authorized");
        }
    }

    @Jpf.Action(
        forwards={
            @Jpf.Forward(name="login_success", path="/mydiary/index.jsp"),
            @Jpf.Forward(name="login_failure", path="/login.jsp")
        }
    )
    public Forward processLogin(LoginForm loginForm) {
        String username = loginForm.getUsername();
        if ((username == null) || (username.length()==0)) {
            return new Forward("login_failure");
        }
        String password = loginForm.getPassword();
        if ((password == null) || (password.length()==0)) {
            return new Forward("login_failure");
        }
        String prefix = username.substring(0, 1);
        String suffix = username.substring(username.length()-1);
        if (isMatched(password, prefix, suffix)) {
            getRequest().getSession().setAttribute("username", username);
            return new Forward("login_success");
        } else {
            return new Forward("login_failure");
        }
    }
    
    private boolean isAuthorized(String username) {
        if ((username !=null) && (username.length()>0)) {
            return true;
        } else {
            return false;
        }
    }
    
    private boolean isMatched(String str, String start, String end) {
        if (str.startsWith(start) && str.endsWith(end) && (str.length()>=6)) {
            return true;
        } else {
            return false;
        }
    }

    public static class LoginForm implements Serializable {
        private String username;
        private String password;
		public String getPassword() {
			return password;
		}
		
		public void setPassword(String password) {
			this.password = password;
		}
		
		public String getUsername() {
			return username;
		}
		
		public void setUsername(String username) {
			this.username = username;
		}
		

    }
}
